clear
set more off

use "$data\Univ_data.dta"

cd "$output"

***************************************************************************************************************************

local ASC_enroll = "ENROLL_FRESH_NON_RES_ALIEN_DEG IN_STATE_FRESHMEN AMERICAN_OOS"

************************************************************************
*** Figure out "balanced" - in the sense - within a year, the same number of universities report all 3 enrollment categories:
gen flag=0
foreach data in Delta ASC{
	foreach dep_vars in  enroll{
			gen `data'_`dep_vars'_flag=0
			replace flag=0
			foreach i in ``data'_`dep_vars''{
				replace flag=1 if l_`i'==.
			}
			replace `data'_`dep_vars'_flag=1 if flag==1
	}
}


gen nom_approp_minus=nominal_approp - 100000*state_ap
gen l_state_app_at_state=log(nom_approp_minus)
local ivs="l_state_app_at_state"

gen l_foreign_fresh=l_ENROLL_FRESH_NON_RES_ALIEN_DEG
gen foreign_fresh=ENROLL_FRESH_NON_RES_ALIEN_DEG
label var foreign_fresh "Foreign Freshmen"
label var l_foreign_fresh "Log(Foreign Freshmen)"
local ASC_enroll = "foreign_fresh IN_STATE_FRESHMEN AMERICAN_OOS"


*** Table 2 and 3 -- Instrumental Variables
foreach indep_var in state_ap{
	foreach data in Delta ASC{

		foreach dep_vars in enroll{
			local k=0
			foreach j in Research   AAU    nonResearch{
				
					preserve
					keep if `j'==1
					drop if `data'_`dep_vars'_flag==1
					sort unitid year
					foreach i in ``data'_`dep_vars''{
						foreach iv in `ivs'{
		
							xtivreg2 l_`i' (l_`indep_var' = `iv') l_population y1-y17 [w=weight], fe cluster(state_of_college) 
							
							xtreg l_`i'  `iv' l_population y1-y17 [w=weight] if e(sample)==1, fe cluster(state_of_college)  
							local p_val=2*ttail(e(df_r),abs( _b[`iv']/_se[`iv']))
							local p_val=round(`p_val',0.0001)
							
							
							**First Stage
							xtreg l_`indep_var'   `iv' l_population y1-y17 [w=weight] if e(sample)==1, fe cluster(state_of_college)  
							if `k'==0{
								outreg2 `iv' l_population using fs_`dep_vars'_`indep_var'_`data'.xls, keep(`iv'  l_population) replace cttop("`: variable label `i''")  se asterisk(se) label bdec(3) sdec(3)
							}
							else{
								outreg2 `iv' l_population using fs_`dep_vars'_`indep_var'_`data'.xls, keep(`iv'  l_population) append cttop("`: variable label `i''")  se asterisk(se) label bdec(3) sdec(3)
							}
						
								
							xtivreg2 l_`i' (l_`indep_var' = `iv') l_population y1-y17 [w=weight], fe cluster(state_of_college) first 
							summ l_`i' if e(sample)==1
							local mean_dep=r(mean)
							local mean_dep=round(`mean_dep',0.01)
							mat first = e(first)
							scalar pr2 = first[3,1]
							scalar Fstat = first[4,1]
							scalar Fpval = first[6,1]
							
							if `k'==0{
								outreg2 l_`indep_var' l_population  using IV_`dep_vars'_`indep_var'_`data'.xls, keep(l_`indep_var' l_population) replace cttop("`: variable label `i''") addstat(Partial R-squared, pr2, F-Test of ivs, Fstat) addtext(Sample, `j', Data, `data', Style, "Logs", Weights, "Undergrad Population", Fixed Effects, "University and Year", Cluster, "State Level", IV, `iv') se asterisk(se) label bdec(3) sdec(3)
							}
							else{
								outreg2 l_`indep_var' l_population  using IV_`dep_vars'_`indep_var'_`data'.xls, keep(l_`indep_var' l_population)  append cttop("`: variable label `i''") addstat(Partial R-squared, pr2, F-Test of ivs, Fstat) addtext(Sample, `j', Data, `data', Style, "Logs", Weights, "Undergrad Population", Fixed Effects, "University and Year", Cluster, "State Level", IV, `iv') se asterisk(se) label bdec(3) sdec(3)
							}
						
							local k=1
					
							
							
						
					}	
				}

				restore
			}
		}
	}
}




**********************

local ASC_enroll = "foreign_fresh"

**** Table 4 ---HETEROGENIETY

keep if Research==1

gen float fres=research01/eandg01
gen float foos=AMERICAN_OOS/FRESH_MEN_WOMEN_TOT_ENR
gen sat75m=FRESH_SAT_I_M_75_PCTL
gen sat25m=FRESH_SAT_I_M_25_PCTL
gen sat25v = FRESH_SAT_I_V_25_PCTL
gen oos=AMERICAN_OOS
gen ffor=foreign_fresh/FRESH_MEN_WOMEN_TOT_ENR
gen sfrac=state_ap/total03_revenue

gen rank_high=1 if inlist(unitid, 110635, 110662, 170976, 199120, 228778, 234076, 174066)
gen rank_low=1 if rank_high!=1


					local hetero="sfrac sat75m fres foos ffor"
					foreach het in `hetero'{
						egen float b2_`het'=mean(`het') if year<1999, by(unitid)
						egen float b_`het'=mean(b2_`het'), by(unitid)
						*egen m_`het'=median(b_`het')
						egen float m_`het'=pctile(b_`het'), p(50)
						gen `het'_high=(b_`het'>m_`het') & b_`het'<.
						gen `het'_low=b_`het'<=m_`het'
					}


					egen new=cut(b_foos), group(3)
					gen low_oos=(new==0)
					gen med_oos=(new==1)
					gen high_oos=(new==2)

					
					
local het_type="sat75m_high sat75m_low fres_high fres_low low_oos med_oos high_oos"


*** IV for Appropriations
foreach indep_var in state_ap{
	foreach data in ASC{
		foreach dep_vars in  enroll{
			local k=0
			foreach j in `het_type'{	
					preserve
					
					drop if `data'_`dep_vars'_flag==1
					
					

					keep if `j'==1
					
					sort unitid year
					foreach i in ``data'_`dep_vars''{
						foreach iv in `ivs'{
										
							xtivreg2 l_`i' (l_`indep_var' = `iv') l_population y1-y17 [w=weight], fe cluster(state_of_college) 
							
							xtreg l_`i'  `iv' l_population y1-y17 [w=weight] if e(sample)==1, fe cluster(state_of_college)  
							local p_val=2*ttail(e(df_r),abs( _b[`iv']/_se[`iv']))
							local p_val=round(`p_val',0.0001)

	
							xtivreg2 l_`i' (l_`indep_var' = `iv') l_population y1-y17 [w=weight], fe cluster(state_of_college) first 
							summ l_`i' if e(sample)==1
							local mean_dep=r(mean)
							local mean_dep=round(`mean_dep',0.01)
							mat first = e(first)
							scalar pr2 = first[3,1]
							scalar Fstat = first[4,1]
							scalar Fpval = first[6,1]
							
							if `k'==0{
								outreg2 l_`indep_var' l_population  using IV_`dep_vars'_`indep_var'_`data'_hetero.xls, keep(l_`indep_var' l_population) replace cttop("`: variable label `i''") addstat(Partial R-squared, pr2, F-Test of ivs, Fstat) addtext(Sample, `j', Data, `data', Style, "Logs", Weights, "Undergrad Population", Fixed Effects, "University and Year", Cluster, "State Level", IV, `iv') se asterisk(se) label bdec(3) sdec(3)
							}
							else{
								outreg2 l_`indep_var' l_population  using IV_`dep_vars'_`indep_var'_`data'_hetero.xls, keep(l_`indep_var' l_population)  append cttop("`: variable label `i''") addstat(Partial R-squared, pr2, F-Test of ivs, Fstat) addtext(Sample, `j', Data, `data', Style, "Logs", Weights, "Undergrad Population", Fixed Effects, "University and Year", Cluster, "State Level", IV, `iv') se asterisk(se) label bdec(3) sdec(3)
							}
						
							local k=1
						
					}	
				}

				restore
			}
		}
	}
}
